==> snEADy1.0.zip: src/de/farafin/snEADy/communication/I_PlayFieldConstants.java <==
/*
 * Created on 01.12.2004
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.farafin.snEADy.communication;

/**
 * An interface for interpretation of the character of the playfield
 * 
 * @author roland
 *
 * @see de.farafin.snEADy.communication.D_Level
 * @see de.farafin.snEADy.world.C_Arena
 * @see de.farafin.snEADy.player
 * 
 *  @version $Revision: 1.11 $ 
 */ 
public interface I_PlayFieldConstants
{
	/** free field */			public static final char FREE =		'.';
	/** blocked field */		public static final char WALL =		'#';
	
	/** player 0 */				public static final char PLAYER_0 =	'0';
	/** player 1 */				public static final char PLAYER_1 =	'1';
	/** player 2 */				public static final char PLAYER_2 =	'2';
	/** player 3 */				public static final char PLAYER_3 =	'3';
	/** player 4 */				public static final char PLAYER_4 =	'4';
	/** player 5 */				public static final char PLAYER_5 =	'5';
	/** player 6 */				public static final char PLAYER_6 =	'6';
	/** player 7 */				public static final char PLAYER_7 =	'7';
	/** player 8 */				public static final char PLAYER_8 =	'8';
	/** player 9 */				public static final char PLAYER_9 =	'9';

	/** speed goody */			public static final char LENGTH  = 	'a';
	/** length goody */			public static final char SPEED   = 	'b';
	/** points goody */			public static final char POINTS  = 	'c';
	/** goody */				public static final char SLOW    = 	'd';
	/** goody */				public static final char SHORT   = 	'e';
	/** goody */				public static final char GOODY_f = 	'f';
	/** goody */				public static final char GOODY_g = 	'g';
	/** goody */				public static final char GOODY_h = 	'h';
	/** goody */				public static final char GOODY_i = 	'i';
	/** goody */				public static final char GOODY_j = 	'j';
	/** goody */				public static final char GOODY_k = 	'k';
	/** goody */				public static final char GOODY_l = 	'l';
	/** goody */				public static final char GOODY_m = 	'm';
	/** goody */				public static final char GOODY_n = 	'n';
	/** goody */				public static final char GOODY_o = 	'o';
	/** goody */				public static final char GOODY_p = 	'p';
	/** goody */				public static final char GOODY_q = 	'q';
	/** goody */				public static final char GOODY_r = 	'r';
	/** goody */				public static final char GOODY_s = 	's';
	/** goody */				public static final char GOODY_t = 	't';
	/** goody */				public static final char GOODY_u = 	'u';
	/** goody */				public static final char GOODY_v = 	'v';
	/** goody */				public static final char GOODY_w = 	'w';
	/** goody */				public static final char GOODY_x = 	'x';
	/** goody */				public static final char GOODY_y = 	'y';
	/** goody */				public static final char GOODY_z = 	'z';
	
	/** field */				public static final char EXIT =		'A';
	/** field */				public static final char FIELD_B =	'B';
	/** field */				public static final char FIELD_C =	'C';
	/** field */				public static final char FIELD_D =	'D';
	/** field */				public static final char FIELD_E =	'E';
	/** field */				public static final char FIELD_F =	'F';
	/** field */				public static final char FIELD_G =	'G';
	/** field */				public static final char FIELD_H =	'H';
	/** field */				public static final char FIELD_I =	'I';
	/** field */				public static final char FIELD_J =	'J';
	/** field */				public static final char FIELD_K =	'K';
	/** field */				public static final char FIELD_L =	'L';
	/** field */				public static final char FIELD_M =	'M';
	/** field */				public static final char FIELD_N =	'N';
	/** field */				public static final char FIELD_O =	'O';
	/** field */				public static final char FIELD_P =	'P';
	/** field */				public static final char FIELD_Q =	'Q';
	/** field */				public static final char FIELD_R =	'R';
	/** field */				public static final char FIELD_S =	'S';
	/** field */				public static final char FIELD_T =	'T';
	/** field */				public static final char FIELD_U =	'U';
	/** field */				public static final char FIELD_V =	'V';
	/** field */				public static final char FIELD_W =	'W';
	/** field */				public static final char FIELD_X =	'X';
	/** field */				public static final char FIELD_Y =	'Y';
	/** field */				public static final char FIELD_Z =	'Z';
}

==> snEADy1.019.zip: src/de/farafin/snEADy/communication/I_PlayFieldConstants.java <==
/*
 * Created on 01.12.2004
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.farafin.snEADy.communication;

/**
 * An interface for interpretation of the character of the playfield
 * 
 * @author roland
 *
 * @see de.farafin.snEADy.communication.D_Level
 * @see de.farafin.snEADy.world.C_Arena
 * @see de.farafin.snEADy.player
 * 
 *  @version $Revision: 1.12 $ 
 */ 
public interface I_PlayFieldConstants
{
	/** free field */			public static final char FREE =		'.';
	/** blocked field */		public static final char WALL =		'#';
	
	/** player 0 */				public static final char PLAYER_0 =	'0';
	/** player 1 */				public static final char PLAYER_1 =	'1';
	/** player 2 */				public static final char PLAYER_2 =	'2';
	/** player 3 */				public static final char PLAYER_3 =	'3';
	/** player 4 */				public static final char PLAYER_4 =	'4';
	/** player 5 */				public static final char PLAYER_5 =	'5';
	/** player 6 */				public static final char PLAYER_6 =	'6';
	/** player 7 */				public static final char PLAYER_7 =	'7';
	/** player 8 */				public static final char PLAYER_8 =	'8';
	/** player 9 */				public static final char PLAYER_9 =	'9';

	/** start of goodies */		public static final char GOODY_START  = 	'a';
	/** speed goody */			public static final char LENGTH  = 	'a';
	/** length goody */			public static final char SPEED   = 	'b';
	/** points goody */			public static final char POINTS  = 	'c';
	/** goody */				public static final char SLOW    = 	'd';
	/** goody */				public static final char SHORT   = 	'e';
	/** goody */				public static final char GOODY_f = 	'f';
	/** goody */				public static final char GOODY_g = 	'g';
	/** goody */				public static final char GOODY_h = 	'h';
	/** goody */				public static final char GOODY_i = 	'i';
	/** goody */				public static final char GOODY_j = 	'j';
	/** goody */				public static final char GOODY_k = 	'k';
	/** goody */				public static final char GOODY_l = 	'l';
	/** goody */				public static final char GOODY_m = 	'm';
	/** goody */				public static final char GOODY_n = 	'n';
	/** goody */				public static final char GOODY_o = 	'o';
	/** goody */				public static final char GOODY_p = 	'p';
	/** goody */				public static final char GOODY_q = 	'q';
	/** goody */				public static final char GOODY_r = 	'r';
	/** goody */				public static final char GOODY_s = 	's';
	/** goody */				public static final char GOODY_t = 	't';
	/** goody */				public static final char GOODY_u = 	'u';
	/** goody */				public static final char GOODY_v = 	'v';
	/** goody */				public static final char GOODY_w = 	'w';
	/** goody */				public static final char GOODY_x = 	'x';
	/** goody */				public static final char GOODY_y = 	'y';
	/** goody */				public static final char GOODY_z = 	'z';
	/** end of goodies */		public static final char GOODY_LAST  = 	'z';

	
	/** field */				public static final char EXIT =		'A';
	/** field */				public static final char FIELD_B =	'B';
	/** field */				public static final char FIELD_C =	'C';
	/** field */				public static final char FIELD_D =	'D';
	/** field */				public static final char FIELD_E =	'E';
	/** field */				public static final char FIELD_F =	'F';
	/** field */				public static final char FIELD_G =	'G';
	/** field */				public static final char FIELD_H =	'H';
	/** field */				public static final char FIELD_I =	'I';
	/** field */				public static final char FIELD_J =	'J';
	/** field */				public static final char FIELD_K =	'K';
	/** field */				public static final char FIELD_L =	'L';
	/** field */				public static final char FIELD_M =	'M';
	/** field */				public static final char FIELD_N =	'N';
	/** field */				public static final char FIELD_O =	'O';
	/** field */				public static final char FIELD_P =	'P';
	/** field */				public static final char FIELD_Q =	'Q';
	/** field */				public static final char FIELD_R =	'R';
	/** field */				public static final char FIELD_S =	'S';
	/** field */				public static final char FIELD_T =	'T';
	/** field */				public static final char FIELD_U =	'U';
	/** field */				public static final char FIELD_V =	'V';
	/** field */				public static final char FIELD_W =	'W';
	/** field */				public static final char FIELD_X =	'X';
	/** field */				public static final char FIELD_Y =	'Y';
	/** field */				public static final char FIELD_Z =	'Z';
}
